package com.trade.service.trade.salesorder.service.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.trade.service.trade.salesorder.domain.CustomsDeclaration;
import com.trade.service.trade.salesorder.mapper.CustomsDeclarationMapper;
import com.trade.service.trade.salesorder.service.ICustomsDeclarationGoodsService;
import com.trade.service.trade.salesorder.service.ICustomsDeclarationService;
import com.trade.service.trade.salesorder.vo.CustomsDeclarationDtlVO;
import com.trade.service.trade.salesorder.vo.CustomsDeclarationSearch;
import com.trade.service.trade.salesorder.vo.CustomsDeclarationVO;
import com.trade.service.trade.salesorder.vo.SalesOrder4CustomsDeclarationVO;
import org.springframework.stereotype.Service;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

import javax.annotation.Resource;
import java.util.List;

/**
 * <p>
 * 报关单信息 服务实现类
 * </p>
 *
 * @author zhangchenm
 * @since 2024-09-19
 */
@Service
public class CustomsDeclarationServiceImpl extends ServiceImpl<CustomsDeclarationMapper, CustomsDeclaration> implements ICustomsDeclarationService {

    @Resource
    private ICustomsDeclarationGoodsService customsDeclarationGoodsService;

    @Override
    public void addCustomsDeclaration(CustomsDeclaration customsDeclaration) {
        this.save(customsDeclaration);
    }

    @Override
    public CustomsDeclaration getByBgdh(String bgdh) {
        return this.lambdaQuery().eq(CustomsDeclaration::getBgdhgbh, bgdh).one();
    }

    @Override
    public void updateCustomsDeclaration(CustomsDeclaration customsDeclaration) {
        this.updateById(customsDeclaration);
    }

    @Override
    public List<SalesOrder4CustomsDeclarationVO> queryOrderNo4UpdateCustomsDeclaration() {
        return this.baseMapper.queryOrderNo4UpdateCustomsDeclaration();
    }

    @Override
    public PageInfo<CustomsDeclarationVO> queryListBySearch(CustomsDeclarationSearch search) {
        PageHelper.startPage(search.getPage(), search.getRows());
        List<CustomsDeclarationVO> list = this.baseMapper.queryListBySearch(search);
        return new PageInfo<>(list);
    }

    @Override
    public CustomsDeclarationDtlVO getDetailById(Long id) {
        // todo 补充委托报关协议编号 和 委托保管协议文件
        CustomsDeclarationDtlVO customsDeclarationDtlVO = this.baseMapper.getDetailById(id);
        customsDeclarationDtlVO
                .setHggq(customsDeclarationDtlVO.getSbhggqkajc() + "(" + customsDeclarationDtlVO.getSbhggqkaDm() + ")");
        customsDeclarationDtlVO.setCustomsDeclarationGoodsDtlVOList(customsDeclarationGoodsService
                .listWithCustomsDeclarationDtlByOrderId(customsDeclarationDtlVO.getOrderId()));
        return customsDeclarationDtlVO;
    }
}
